Enum promkit::PromptSignal
source · pub enum PromptSignal {
Continue,
Quit,
}Expand description
Represents the signal to control the flow of a prompt.
This enum is used to indicate whether a prompt should continue running or quit based on user input or other conditions.
Variants
Continue
Indicates that the prompt should continue to run and handle further events.
Quit
Indicates that the prompt should quit and terminate its execution.