Json

Struct Json 

pub struct Json {
    pub renderer: Option<SharedRenderer<Index>>,
    pub evaluator: Evaluator<Self>,
    pub title: State,
    pub json: State,
}
Available on crate feature json only.
Represents a JSON preset for rendering JSON data and titles with customizable styles.

Fields

renderer: Option<SharedRenderer<Index>>

Shared renderer for the prompt, allowing for rendering of UI components.

evaluator: Evaluator<Self>

Function to evaluate the input events and update the state of the prompt.

title: State

State for the title text.

json: State

State for the JSON data, including formatting and rendering options.

Implementations

Source

impl Json

pub fn new(stream: JsonStream) -> Self

Creates a new JSON preset with the provided JSON stream.

pub fn title<T: AsRef<str>>(self, text: T) -> Self

Sets the title text for the JSON preset.

pub fn title_style(self, style: ContentStyle) -> Self

Sets the style for the title text.

pub fn json_lines(self, lines: usize) -> Self

Sets the number of lines to be used for rendering the JSON data.

pub fn indent(self, indent: usize) -> Self

Sets the indentation level for rendering the JSON data.

pub fn overflow_mode(self, mode: OverflowMode) -> Self

Sets the overflow mode for rendering JSON values that exceed the available width.

pub fn active_item_attribute(self, attr: Attribute) -> Self

Sets the attribute for active (currently selected) items.

pub fn inactive_item_attribute(self, attr: Attribute) -> Self

Sets the attribute for inactive (not currently selected) items.

pub fn evaluator(self, evaluator: Evaluator<Self>) -> Self

Sets the evaluator function for handling events in the JSON preset.