pub struct Json {
pub renderer: Option<SharedRenderer<Index>>,
pub evaluator: Evaluator<Self>,
pub title: State,
pub json: State,
}Available on crate feature
json only.Expand description
Represents a JSON preset for rendering JSON data and titles with customizable styles.
Fields
renderer: Option<SharedRenderer<Index>>Shared renderer for the prompt, allowing for rendering of UI components.
evaluator: Evaluator<Self>Function to evaluate the input events and update the state of the prompt.
title: StateState for the title text.
json: StateState for the JSON data, including formatting and rendering options.
Implementations
Sourceimpl Json
impl Json
Sourcepub fn new(stream: JsonStream) -> Self
pub fn new(stream: JsonStream) -> Self
Creates a new JSON preset with the provided JSON stream.
Sourcepub fn title_style(self, style: ContentStyle) -> Self
pub fn title_style(self, style: ContentStyle) -> Self
Sets the style for the title text.
Sourcepub fn json_lines(self, lines: usize) -> Self
pub fn json_lines(self, lines: usize) -> Self
Sets the number of lines to be used for rendering the JSON data.
Sourcepub fn indent(self, indent: usize) -> Self
pub fn indent(self, indent: usize) -> Self
Sets the indentation level for rendering the JSON data.
Sourcepub fn overflow_mode(self, mode: OverflowMode) -> Self
pub fn overflow_mode(self, mode: OverflowMode) -> Self
Sets the overflow mode for rendering JSON values that exceed the available width.
Sourcepub fn active_item_attribute(self, attr: Attribute) -> Self
pub fn active_item_attribute(self, attr: Attribute) -> Self
Sets the attribute for active (currently selected) items.
Sourcepub fn inactive_item_attribute(self, attr: Attribute) -> Self
pub fn inactive_item_attribute(self, attr: Attribute) -> Self
Sets the attribute for inactive (not currently selected) items.